package FASTA::FileIn;
BEGIN{ push(@INC, $ENV{IS_SCRIPTS}); }
use Carp;
use warnings;
use strict;
use FASTA::Sequence;

my $MILLION = 1000000;

###################################################
sub new {
    my $pkg = shift;
    my $prefix = shift;
    bless {
	filename => undef, 
	fileHandler => undef, 
	numReads => 0,
	prefix => $prefix
    }, $pkg;
}

###################################################
sub open {
    my $self = shift;
    my $filename = shift or croak "File name is not specified.";
    $self->{filename} = $filename;
    open $self->{fileHandler}, $filename 
	or croak "Can't open $filename to read.";
    print $self->{prefix} . " "
	. "Parsing a FastA file...\n"
	. "\tfilename = " . $filename . "\n";
}

###################################################
sub close {
    my $self = shift;
    close $self->{fileHandler};
    print $self->{prefix} . " "
	. "\t" . $self->{numReads} . " sequences were loaded from "
	. $self->{filename} . ".\n"
	. "...done.\n\n";
}

###################################################
sub fetchSequence {
    my $self = shift;
    my $fh = $self->{fileHandler};
    my $flgSeqLine = 0;
    my $fastaSeq = FASTA::Sequence->new();
    while(<$fh>){
	chomp;
	if( /^>(.+)$/ ){
	    if( $flgSeqLine == 0 ){
		$fastaSeq->setTitle($1);
		$flgSeqLine = 1;
	    } else {
		use bytes;
		my $numBytes = length($_."\n");
		seek($fh, -1*$numBytes, 1);
		++$self->{numReads};
		$self->progressReport();
		return $fastaSeq;
	    }
	} elsif( /(\w+)/ ) {
	    if( $flgSeqLine ){
		$fastaSeq->appendSequence($_);
	    }
	}
    }
    if( $flgSeqLine ){
	++$self->{numReads};
	return $fastaSeq;
    }
    return 0;
}

###################################################
sub progressReport {
    my $self = shift;
    if( $self->{numReads} % $MILLION == 0 ){
	print $self->{prefix} . " "
	    . "\t" . $self->{numReads}/$MILLION
	    . " million sequences were loaded from "
	    . $self->{filename} . ".\n";
    }
}

1;
